package singldubldemo;

import java.util.UUID;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.*;
import org.springframework.stereotype.Component;

/**
 * Diese Demo zeigt:
 * a) In Spring koennen mehrere Spring-Application-Kontexte parallel erzeugt werden.
 *    Bei Spring-MVC-Anwendungen ist dies sogar der Normalfall.
 * b) Spring-Singleton-Beans sind keine echten GoF-Singletons, die es pro ClassLoader nur einmal gibt,
 *    sondern sie sind nur pro Spring-ApplicationContext einmalig.
 *    Bei mehreren Spring-Application-Kontexten kann es mehrere Instanzen einer Spring-Singleton-Bean geben.
 */
public class MainApp
{
   public static void main( String[] args )
   {
      AnnotationConfigApplicationContext appRootContext = new AnnotationConfigApplicationContext();
      appRootContext.register( RootConfig.class );
      appRootContext.refresh();

      AnnotationConfigApplicationContext servletContext = new AnnotationConfigApplicationContext();
      servletContext.register( WebConfig.class );
      servletContext.refresh();

      MeinSingleton singletonRt = (MeinSingleton) appRootContext.getBean( "meinSingleton" );
      MeinSingleton singletonWb = (MeinSingleton) servletContext.getBean( "meinSingleton" );

      System.out.println( "\n---- Die beiden Singleton-Instanzen sind " + (singletonRt.id.equals( singletonWb.id ) ? "identisch." : "verschieden.") );
   }
}

@Configuration
@ComponentScan( basePackages = { "singldubldemo" } )
class RootConfig
{ /* ... */
}

@Configuration
@ComponentScan( basePackages = { "singldubldemo" } )
class WebConfig
{ /* ... */
}

@Component
@Scope( ConfigurableBeanFactory.SCOPE_SINGLETON )
class MeinSingleton
{
   public final String id = UUID.randomUUID().toString();
}
