package didemo;

import javax.sql.DataSource;
import org.apache.commons.dbcp2.BasicDataSource;
import org.springframework.context.annotation.*;
import org.springframework.jdbc.datasource.embedded.*;
import org.springframework.jndi.JndiObjectFactoryBean;

@Configuration
public class MeineDataSource
{
   // DataSource fuer "Entwicklung" und JUnit-Modultests:
   @Bean( destroyMethod="shutdown" )
   @Profile( "dev" )
   public DataSource dataSource1()
   {
      return new EmbeddedDatabaseBuilder()
            .setType( EmbeddedDatabaseType.H2 )
            .addScript( "classpath:schema.sql" )
            .addScript( "classpath:test-data.sql" )
            .build();
   }

   // DataSource fuer "Integrationstest" (URL-Pfad anpassen!):
   @Bean
   @Profile( "test" )
   public DataSource dataSource2()
   {
      BasicDataSource ds = new BasicDataSource();
      ds.setDriverClassName( "org.h2.Driver" );
      ds.setUrl( "jdbc:h2:./target/h2-db;DB_CLOSE_ON_EXIT=FALSE" );
      ds.setUsername( "sa" );
      ds.setPassword( "" );
      return ds;
   }

   // DataSource fuer "Produktion" (JNDI-Name appassen!):
   @Bean
   @Profile( "prod" )
   public DataSource dataSource3()
   {
      JndiObjectFactoryBean factBean = new JndiObjectFactoryBean();
      factBean.setJndiName( "jdbc/meineDataSource" );
      factBean.setResourceRef( true );
      factBean.setProxyInterface( javax.sql.DataSource.class );
      return (DataSource) factBean.getObject();
   }
}
