package mvcdemo;

import org.springframework.web.servlet.support.AbstractAnnotationConfigDispatcherServletInitializer;

/**
 * DispatcherServlet-Konfiguration:
 * Jede Klasse, die AbstractAnnotationConfigDispatcherServletInitializer erweitert, wird automatisch verwendet,
 * um das DispatcherServlet zu konfigurieren, und um zwei Spring Application Contexte zu erstellen.
 */
public class WebAppInitializer extends AbstractAnnotationConfigDispatcherServletInitializer
{
   /** Vom ContextLoaderListener erzeugter Spring Application Context fuer die Beans im Backend, Middle-Tier und Data-Tier
       (wird in diesem simplen Beispiel nicht benoetigt) */
   @Override
   protected Class<?>[] getRootConfigClasses() {
      return null;
   }

   /** Konfiguration des DispatcherServlet Spring Application Servlet Context fuer die Webkomponenten wie
       Controller, View-Resolver und Handler-Mappings */
   @Override
   protected Class<?>[] getServletConfigClasses() {
      return new Class[] { WebMvcConfig.class };
   }

   /** Mapping vom DispatcherServlet auf den Kontextpfad "/" */
   @Override
   protected String[] getServletMappings() {
      return new String[] { "/" };
   }
}
