package mvcdemo;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.ViewResolver;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;
import org.thymeleaf.spring3.SpringTemplateEngine;
import org.thymeleaf.spring3.view.ThymeleafViewResolver;
import org.thymeleaf.templateresolver.ServletContextTemplateResolver;

/** Webkonfiguration fuer Spring MVC und Thymeleaf */
@Configuration
@ComponentScan
@EnableWebMvc
public class WebMvcConfig extends WebMvcConfigurerAdapter
{
   @Override
   public void addResourceHandlers( ResourceHandlerRegistry registry )
   {
      registry.addResourceHandler( "/**" ).addResourceLocations( "/" );
   }

   @Bean
   public ViewResolver viewResolver()
   {
      ServletContextTemplateResolver templateResolver = new ServletContextTemplateResolver();
      templateResolver.setCacheable( false );
      templateResolver.setPrefix( "/templates/" );
      templateResolver.setSuffix( ".html" );
      templateResolver.setTemplateMode( "HTML5" );

      SpringTemplateEngine templateEngine = new SpringTemplateEngine();
      templateEngine.setTemplateResolver( templateResolver );

      ThymeleafViewResolver viewResolver = new ThymeleafViewResolver();
      viewResolver.setCharacterEncoding( "UTF-8" );
      viewResolver.setOrder( 1 );
      viewResolver.setTemplateEngine( templateEngine );

      return viewResolver;
   }
}
