package mvcdemo;

import static org.hamcrest.Matchers.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;
import static org.springframework.test.web.servlet.setup.MockMvcBuilders.standaloneSetup;
import java.util.*;
import org.junit.Test;
import org.mockito.ArgumentMatchers;
import org.mockito.Mockito;
import org.springframework.test.web.servlet.MockMvc;

public class DatenMockControllerTest
{
   @Test
   public void testPost() throws Exception
   {
      MeineEntity meineEntityMock = new MeineEntity( null, null, "Mein Test-Text" );
      DatenRepository datenRepositoryMock = Mockito.mock( DatenRepository.class );

      MeineEntityController controller = new MeineEntityController( datenRepositoryMock );
      MockMvc mockMvc = standaloneSetup( controller ).build();

      mockMvc.perform( post( "/mvc-th" )
            .param( "text", "Mein Test-Text" ) )
            .andExpect( status().is3xxRedirection() )
            .andExpect( redirectedUrl( "/mvc-th" ) );

      // Dieser Test ueberprueft die Datenfelder des Mock-Objekts, aber nicht das Mock-Objekt selbst:
      Mockito.verify( datenRepositoryMock ).addToRepository( ArgumentMatchers.refEq( meineEntityMock ) );

      // Dieser Test ueberprueft das Mock-Objekt auf Gleichheit, aber er funktioniert nur,
      // wenn MeineEntity equals(Object) geeignet implementiert ist: 
      Mockito.verify( datenRepositoryMock, Mockito.atLeastOnce() ).addToRepository( meineEntityMock );
   }

   @Test
   public void testGet() throws Exception
   {
      List<MeineEntity> erwarteteEntities = new ArrayList<>();
      erwarteteEntities.add( new MeineEntity( Long.valueOf(   42 ), new Date(), "Mein erster Text"  ) );
      erwarteteEntities.add( new MeineEntity( Long.valueOf( 4711 ), new Date(), "Mein zweiter Text" ) );

      DatenRepository datenRepositoryMock = Mockito.mock( DatenRepository.class );
      Mockito.when( datenRepositoryMock.getAll() ).thenReturn( erwarteteEntities );

      MeineEntityController controller = new MeineEntityController( datenRepositoryMock );
      MockMvc mockMvc = standaloneSetup( controller ).build();

      mockMvc.perform( get( "/mvc-th" ) )
            .andExpect( status().isOk() )
            .andExpect( view().name( "MeineEntityWebseite" ) )
            .andExpect( model().attributeExists( "entitiesListe" ) )
            .andExpect( model().attribute( "entitiesListe", instanceOf( erwarteteEntities.getClass() ) ) )
            .andExpect( model().attribute( "entitiesListe", hasSize(    erwarteteEntities.size() ) ) )
            .andExpect( model().attribute( "entitiesListe", hasItems(   erwarteteEntities.toArray() ) ) );
   }
}
