package mvcdemo;

import static org.hamcrest.Matchers.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;
import static org.springframework.test.web.servlet.setup.MockMvcBuilders.standaloneSetup;
import java.util.List;
import org.junit.*;
import org.springframework.test.web.servlet.*;

public class MeineEntityControllerTest
{
   @Test
   public void testMeineEntityController() throws Exception
   {
      MeineEntityController controller = new MeineEntityController( new DatenRepositoryImpl() );
      MockMvc mockMvc = standaloneSetup( controller ).build();

      mockMvc.perform( post( "/mvc-th" )
            .param( "text", "Mein Test-Text" ) )
            .andExpect( status().is3xxRedirection() )
            .andExpect( redirectedUrl( "/mvc-th" ) );

      MvcResult mvcResult = mockMvc.perform( get( "/mvc-th" ) )
            .andExpect( status().isOk() )
            .andExpect( view().name( "MeineEntityWebseite" ) )
            .andExpect( model().attributeExists( "entitiesListe" ) )
            .andExpect( model().attribute( "entitiesListe", instanceOf( List.class ) ) )
            .andExpect( model().attribute( "entitiesListe", hasSize( 1 ) ) )
            .andExpect( model().attribute( "entitiesListe", hasItem( hasProperty( "id",   equalTo( Long.valueOf( 0 ) ) ) ) ) )
            .andExpect( model().attribute( "entitiesListe", hasItem( hasProperty( "date", notNullValue() ) ) ) )
            .andExpect( model().attribute( "entitiesListe", hasItem( hasProperty( "text", equalTo( "Mein Test-Text" ) ) ) ) )
            .andReturn();

      // Der folgende Test ist unnoetig, weil der Text bereits oben ueberprueft wurde,
      // er soll nur eine alternative Testmoeglichkeit demonstrieren:
      Assert.assertEquals( "Mein Test-Text",
            ((List<MeineEntity>) mvcResult.getModelAndView().getModel().get( "entitiesListe" )).get( 0 ).getText() );
   }
}
